package com.chelvc.framework.security.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.security.config.SecurityProperties;
import lombok.Getter;
import lombok.NonNull;

/**
 * 数据安全加解密处理默认实现
 *
 * @author Woody
 * @date 2025/1/3
 */
@Getter
public class DefaultSecurityCipherHandler extends AbstractSecurityCipherHandler implements SecurityCipherHandler {
    private final Cipher encryptor, decrypter;

    public DefaultSecurityCipherHandler(@NonNull SecurityProperties.Crypto properties) {
        super(properties);
        String secret = properties.getSecret(), iv = properties.getIv();
        if (StringUtils.isEmpty(iv)) {
            this.encryptor = AESUtils.getEncryptor(AESUtils.ECB_PKCS5PADDING, secret);
            this.decrypter = AESUtils.getDecrypter(AESUtils.ECB_PKCS5PADDING, secret);
        } else {
            this.encryptor = AESUtils.getEncryptor(AESUtils.CBC_PKCS5PADDING, secret, iv);
            this.decrypter = AESUtils.getDecrypter(AESUtils.CBC_PKCS5PADDING, secret, iv);
        }
    }
}
